'use strict';

var path = require('path');

var _require = require('../utils'),
    ifAnyDep = _require.ifAnyDep,
    hasFile = _require.hasFile,
    hasPkgProp = _require.hasPkgProp,
    fromRoot = _require.fromRoot;

var here = function (p) {
  return path.join(__dirname, p);
};

var useBuiltInBabelConfig = !hasFile('.babelrc') && !hasPkgProp('babel');

var ignores = ['/node_modules/', '/fixtures/', '/__tests__/helpers/', '__mocks__'];

var jestConfig = {
  roots: [fromRoot('src')],
  testEnvironment: ifAnyDep(['webpack', 'rollup', 'react'], 'jsdom', 'node'),
  moduleFileExtensions: ['js', 'jsx', 'json', 'ts', 'tsx'],
  collectCoverageFrom: ['src/**/*.+(js|jsx|ts|tsx)'],
  testMatch: ['**/__tests__/**/*.+(js|jsx|ts|tsx)'],
  testPathIgnorePatterns: [].concat(ignores),
  coveragePathIgnorePatterns: [].concat(ignores, ['src/(umd|cjs|esm)-entry.js$']),
  transformIgnorePatterns: ['[/\\\\]node_modules[/\\\\].+\\.(js|jsx)$'],
  coverageThreshold: {
    global: {
      branches: 100,
      functions: 100,
      lines: 100,
      statements: 100
    }
  }
};

if (useBuiltInBabelConfig) {
  jestConfig.transform = { '^.+\\.js$': here('./babel-transform') };
}

module.exports = jestConfig;