'use strict';

var path = require('path');
var spawn = require('cross-spawn');
var rimraf = require('rimraf');

var _require = require('../../utils'),
    hasPkgProp = _require.hasPkgProp,
    fromRoot = _require.fromRoot,
    resolveBin = _require.resolveBin,
    hasFile = _require.hasFile;

var args = process.argv.slice(2);
var here = function (p) {
  return path.join(__dirname, p);
};

var useBuiltinConfig = !args.includes('--presets') && !hasFile('.babelrc') && !hasPkgProp('babel');
var config = useBuiltinConfig ? ['--presets', here('../../config/babelrc.js')] : [];

var ignore = args.includes('--ignore') ? [] : ['--ignore', '__tests__,__mocks__'];

var copyFiles = args.includes('--no-copy-files') ? [] : ['--copy-files'];

var useSpecifiedOutDir = args.includes('--out-dir');
var outDir = useSpecifiedOutDir ? [] : ['--out-dir', 'dist'];

if (!useSpecifiedOutDir && !args.includes('--no-clean')) {
  rimraf.sync(fromRoot('dist'));
}

var result = spawn.sync(resolveBin('babel-cli', { executable: 'babel' }), [].concat(outDir, copyFiles, ignore, config, ['src']).concat(args), { stdio: 'inherit' });

process.exit(result.status);